@@ -20,15 +20,15 @@ import logging
 from typing import Callable
 
 import numpy as np
-from PyQt6 import QtWidgets
+from PySide6 import QtWidgets
 
-from NanoVNASaver.Analysis.Base import Analysis, QHLine
-from NanoVNASaver.Formatting import (
+from ..Formatting import (
     format_frequency,
     format_gain,
     format_resistance,
     format_vswr,
 )
+from .Base import Analysis, QHLine
 
 logger = logging.getLogger(__name__)
 
