@@ -17,8 +17,8 @@
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 import logging
 
-from NanoVNASaver.Hardware.NanoVNA_H import NanoVNA_H
-from NanoVNASaver.Hardware.Serial import Interface
+from .NanoVNA_H import NanoVNA_H
+from .Serial import Interface
 
 logger = logging.getLogger(__name__)
 
@@ -27,19 +27,25 @@ class NanoVNA_H4(NanoVNA_H):
     name = "NanoVNA-H4"
     screenwidth = 480
     screenheight = 320
-    valid_datapoints = (101, 11, 51, 201, 401)
+    valid_datapoints: tuple[int, ...] = (
+        101,
+        11,
+        51,
+        201,
+        401,
+    )
 
     def __init__(self, iface: Interface):
         super().__init__(iface)
-        self.sweep_max_freq_Hz = 1500e6
+        self.sweep_max_freq_hz = 1500e6
         self.sweep_method = "scan"
         if "Scan mask command" in self.features:
             self.sweep_method = "scan_mask"
 
-    # def read_features(self):
+    # def init_features(self) -> None:
     #     logger.debug("read_features")
     #     super().read_features()
     #     if self.readFirmware().find("DiSlord") > 0:
     #         self.features.add("Customizable data points")
     #         logger.info("VNA has 201 datapoints capability")
-    #         self.valid_datapoints = (201, 11, 51,101)
+    #         self.valid_datapoints: tuple[int, ...] = [201, 11, 51, 101]
