@@ -19,8 +19,9 @@
 import logging
 
 import serial
-from PySide6.QtGui import QImage, QPixmap
+from PySide6.QtGui import QPixmap
 
+from .Convert import get_rgb16_pixmap
 from .NanoVNA import NanoVNA
 from .Serial import Interface
 
@@ -49,15 +50,10 @@ class SV6301A(NanoVNA):
         if not self.connected():
             return QPixmap()
         try:
-            rgba_array = self._capture_data()
-            image = QImage(
-                rgba_array,
-                self.screenwidth,
-                self.screenheight,
-                QImage.Format.Format_RGB16,
-            )
             logger.debug("Captured screenshot")
-            return QPixmap(image)
+            return get_rgb16_pixmap(
+                self._capture_data(), self.screenwidth, self.screenheight
+            )
         except serial.SerialException as exc:
             logger.exception("Exception while capturing screenshot: %s", exc)
         return QPixmap()
