@@ -54,7 +54,7 @@ from .Charts.Chart import Chart
 from .Controls.MarkerControl import MarkerControl
 from .Controls.SerialControl import SerialControl
 from .Controls.SweepControl import SweepControl
-from .Defaults import APP_SETTINGS, get_app_config
+from .Defaults import APP_SETTINGS, AppSettings, get_app_config
 from .Formatting import format_frequency, format_gain, format_vswr
 from .Hardware.Hardware import Interface
 from .Hardware.VNA import VNA
@@ -81,6 +81,7 @@ logger = logging.getLogger(__name__)
 
 WORKING_KILL_TIME_MS = 10 * 1000
 
+
 class Communicate(QObject):
     data_available = QtCore.Signal()
 
@@ -95,7 +96,7 @@ class NanoVNASaver(QWidget):
         self.s21att = 0.0
         self.setWindowIcon(get_window_icon())
         # TODO APP_SETTINGS should be used instead app.setting\
-        self.settings = APP_SETTINGS
+        self.settings: AppSettings = APP_SETTINGS
         app_config = self.settings.restore_config()
         self.threadpool = QtCore.QThreadPool()
         self.sweep = Sweep()
@@ -105,7 +106,7 @@ class NanoVNASaver(QWidget):
         self.worker.signals.finished.connect(self.sweepFinished)
         self.worker.signals.sweep_error.connect(self.showSweepError)
 
-        self.markers = []
+        self.markers: list[Marker] = []
         self.marker_ref = False
 
         self.marker_column = QtWidgets.QVBoxLayout()
@@ -114,7 +115,7 @@ class NanoVNASaver(QWidget):
         self.marker_frame.setLayout(self.marker_column)
 
         self.interface = Interface("serial", "None")
-        self.vna: type[VNA] = VNA(self.interface)
+        self.vna: VNA = VNA(self.interface)
 
         self.calibration: Calibration = Calibration()
         self.sweep_control = SweepControl(self)
@@ -124,11 +125,11 @@ class NanoVNASaver(QWidget):
             self.sweep_control.update_sweep_btn
         )
 
-        self.bands = BandsModel()
+        self.bands: BandsModel = BandsModel()
 
         self.dataLock = threading.Lock()
-        self.data = Touchstone()
-        self.ref_data = Touchstone()
+        self.data: Touchstone = Touchstone()
+        self.ref_data: Touchstone = Touchstone()
 
         self.sweepSource = ""
         self.referenceSource = ""
@@ -146,9 +147,7 @@ class NanoVNASaver(QWidget):
         outer.addWidget(scrollarea)
         self.setLayout(outer)
         scrollarea.setWidgetResizable(True)
-        self.resize(
-            app_config.gui.window_width, app_config.gui.window_height
-        )
+        self.resize(app_config.gui.window_width, app_config.gui.window_height)
         scrollarea.setSizePolicy(
             QtWidgets.QSizePolicy.Policy.MinimumExpanding,
             QtWidgets.QSizePolicy.Policy.MinimumExpanding,
@@ -204,7 +203,7 @@ class NanoVNASaver(QWidget):
                 "log_mag": CombinedLogMagChart("S11 & S21 LogMag"),
             },
         }
-        self.tdr_chart = TDRChart("TDR")
+        self.tdr_chart: TDRChart = TDRChart("TDR")
         self.tdr_mainwindow_chart = TDRChart("TDR")
 
         # List of all the S11 charts, for selecting
@@ -261,9 +260,9 @@ class NanoVNASaver(QWidget):
         #  Windows
         ###############################################################
 
-        self.windows = {
+        self.windows: dict[str, QtWidgets.QDialog] = {
             "about": AboutWindow(self),
-            # "analysis": AnalysisWindow(self),
+            "analysis": AnalysisWindow(self),
             "calibration": CalibrationWindow(self),
             "device_settings": DeviceSettingsWindow(self),
             "file": FilesWindow(self),
@@ -342,7 +341,6 @@ class NanoVNASaver(QWidget):
 
         # self.marker_column.addStretch(1)
 
-        self.windows["analysis"] = AnalysisWindow(self)
         btn_show_analysis = QtWidgets.QPushButton("Analysis ...")
         btn_show_analysis.setMinimumHeight(20)
         btn_show_analysis.clicked.connect(
@@ -474,8 +472,6 @@ class NanoVNASaver(QWidget):
         # Run the device data update
         if not self.vna.connected():
             return
-        self.worker.start()
-
         self._sweep_control(start=True)
 
         for m in self.markers:
@@ -487,7 +483,10 @@ class NanoVNASaver(QWidget):
         self.tdr_result_label.setText("")
 
         logger.debug("Starting worker thread")
-        self.threadpool.start(self.worker)
+        self.worker.start()
+        # TODO: Rewrite to make worker a qrunnable with worker signals
+        # https://www.pythonguis.com/tutorials/multithreading-pyqt6-applications-qthreadpool/
+        # self.threadpool.start(self.worker)
 
     def saveData(self, data, data21, source=None):
         with self.dataLock:
