@@ -18,7 +18,7 @@
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 import logging
 
-from PyQt6 import QtWidgets
+from PySide6 import QtWidgets
 
 logger = logging.getLogger(__name__)
 
